#[non_exhaustive]pub enum NavigationStatus {
UnknownNavigationStatus,
NoGuidance,
EnrouteToDestination,
OffRoute,
ArrivedAtDestination,
UnknownValue(UnknownValue),
}Expand description
The vehicle’s navigation status.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified navigation status.
NoGuidance
The Driver app’s navigation is in FREE_NAV mode.
EnrouteToDestination
Turn-by-turn navigation is available and the Driver app navigation has
entered GUIDED_NAV mode.
OffRoute
The vehicle has gone off the suggested route.
ArrivedAtDestination
The vehicle is within approximately 50m of the destination.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using NavigationStatus::value or NavigationStatus::name.
Implementations