#[non_exhaustive]pub enum PowerSource {
UnknownPowerSource,
Ac,
Usb,
Wireless,
Unplugged,
UnknownValue(UnknownValue),
}Expand description
Type of the charger being used to charge the battery.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownPowerSource
Power source unknown.
Ac
Power source is an AC charger.
Usb
Power source is a USB port.
Wireless
Power source is wireless.
Unplugged
Battery is unplugged.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using PowerSource::value or PowerSource::name.
Implementations