GetVehicleRequest

Struct GetVehicleRequest 

#[non_exhaustive]
pub struct GetVehicleRequest { pub header: Option<RequestHeader>, pub name: String, pub current_route_segment_version: Option<Timestamp>, pub waypoints_version: Option<Timestamp>, /* private fields */ }
GetVehicle request message.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
header: Option<RequestHeader>

The standard Fleet Engine request header.

name: String

Required. Must be in the format providers/{provider}/vehicles/{vehicle}. The provider must be the Project ID (for example, sample-cloud-project) of the Google Cloud Project of which the service account making this call is a member.

current_route_segment_version: Option<Timestamp>

Indicates the minimum timestamp (exclusive) for which Vehicle.current_route_segment is retrieved. If the route is unchanged since this timestamp, the current_route_segment field is not set in the response. If a minimum is unspecified, the current_route_segment is always retrieved.

waypoints_version: Option<Timestamp>

Indicates the minimum timestamp (exclusive) for which Vehicle.waypoints data is retrieved. If the waypoints are unchanged since this timestamp, the vehicle.waypoints data is not set in the response. If this field is unspecified, vehicle.waypoints is always retrieved.

Implementations

Source

impl GetVehicleRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_header<T>(self, v: T) -> Self
where T: Into<RequestHeader>,

Sets the value of header.

Example
use google_maps_fleetengine_v1::model::RequestHeader;
let x = GetVehicleRequest::new().set_header(RequestHeader::default()/* use setters */);
pub fn set_or_clear_header<T>(self, v: Option<T>) -> Self
where T: Into<RequestHeader>,

Sets or clears the value of header.

Example
use google_maps_fleetengine_v1::model::RequestHeader;
let x = GetVehicleRequest::new().set_or_clear_header(Some(RequestHeader::default()/* use setters */));
let x = GetVehicleRequest::new().set_or_clear_header(None::<RequestHeader>);
pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = GetVehicleRequest::new().set_name(format!("providers/{provider_id}/vehicles/{vehicle_id}"));
pub fn set_current_route_segment_version<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of current_route_segment_version.

Example
use wkt::Timestamp;
let x = GetVehicleRequest::new().set_current_route_segment_version(Timestamp::default()/* use setters */);
pub fn set_or_clear_current_route_segment_version<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of current_route_segment_version.

Example
use wkt::Timestamp;
let x = GetVehicleRequest::new().set_or_clear_current_route_segment_version(Some(Timestamp::default()/* use setters */));
let x = GetVehicleRequest::new().set_or_clear_current_route_segment_version(None::<Timestamp>);
pub fn set_waypoints_version<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of waypoints_version.

Example
use wkt::Timestamp;
let x = GetVehicleRequest::new().set_waypoints_version(Timestamp::default()/* use setters */);
pub fn set_or_clear_waypoints_version<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of waypoints_version.

Example
use wkt::Timestamp;
let x = GetVehicleRequest::new().set_or_clear_waypoints_version(Some(Timestamp::default()/* use setters */));
let x = GetVehicleRequest::new().set_or_clear_waypoints_version(None::<Timestamp>);