#[non_exhaustive]pub struct ListVehiclesResponse {
pub vehicles: Vec<Vehicle>,
pub next_page_token: String,
pub total_size: i64,
/* private fields */
}Expand description
ListVehicles response message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vehicles: Vec<Vehicle>Vehicles matching the criteria in the request.
The maximum number of vehicles returned is determined by the page_size
field in the request.
next_page_token: StringToken to retrieve the next page of vehicles, or empty if there are no more vehicles that meet the request criteria.
total_size: i64Required. Total number of vehicles matching the request criteria across all pages.
Implementations
Sourceimpl ListVehiclesResponse
impl ListVehiclesResponse
Sourcepub fn set_vehicles<T, V>(self, v: T) -> Self
pub fn set_vehicles<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListVehiclesResponse::new().set_next_page_token("example");Sourcepub fn set_total_size<T: Into<i64>>(self, v: T) -> Self
pub fn set_total_size<T: Into<i64>>(self, v: T) -> Self