#[non_exhaustive]pub struct SearchTripsResponse {
pub trips: Vec<Trip>,
pub next_page_token: String,
/* private fields */
}Expand description
SearchTrips response message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trips: Vec<Trip>The list of trips for the requested vehicle.
next_page_token: StringPass this token in the SearchTripsRequest to page through list results. The API returns a trip list on each call, and when no more results remain the trip list is empty.
Implementations
Sourceimpl SearchTripsResponse
impl SearchTripsResponse
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = SearchTripsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for SearchTripsResponse
impl Clone for SearchTripsResponse
Sourcefn clone(&self) -> SearchTripsResponse
fn clone(&self) -> SearchTripsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SearchTripsResponse
impl Debug for SearchTripsResponse
Sourceimpl Default for SearchTripsResponse
impl Default for SearchTripsResponse
Sourcefn default() -> SearchTripsResponse
fn default() -> SearchTripsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for SearchTripsResponse
impl Message for SearchTripsResponse
Sourceimpl PartialEq for SearchTripsResponse
impl PartialEq for SearchTripsResponse
impl StructuralPartialEq for SearchTripsResponse