#[non_exhaustive]pub struct SpeedReadingInterval {
pub start_polyline_point_index: i32,
pub end_polyline_point_index: i32,
pub speed: Speed,
/* private fields */
}Expand description
Traffic density indicator on a contiguous segment of a path. Given a path with points P_0, P_1, … , P_N (zero-based index), the SpeedReadingInterval defines an interval and describes its traffic using the following categories.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_polyline_point_index: i32The starting index of this interval in the path. In JSON, when the index is 0, the field will appear to be unpopulated.
end_polyline_point_index: i32The ending index of this interval in the path. In JSON, when the index is 0, the field will appear to be unpopulated.
speed: SpeedTraffic speed in this interval.
Implementations
Sourceimpl SpeedReadingInterval
impl SpeedReadingInterval
Sourcepub fn set_start_polyline_point_index<T: Into<i32>>(self, v: T) -> Self
pub fn set_start_polyline_point_index<T: Into<i32>>(self, v: T) -> Self
Sets the value of start_polyline_point_index.
Example
ⓘ
let x = SpeedReadingInterval::new().set_start_polyline_point_index(42);Sourcepub fn set_end_polyline_point_index<T: Into<i32>>(self, v: T) -> Self
pub fn set_end_polyline_point_index<T: Into<i32>>(self, v: T) -> Self
Sets the value of end_polyline_point_index.
Example
ⓘ
let x = SpeedReadingInterval::new().set_end_polyline_point_index(42);Trait Implementations
Sourceimpl Clone for SpeedReadingInterval
impl Clone for SpeedReadingInterval
Sourcefn clone(&self) -> SpeedReadingInterval
fn clone(&self) -> SpeedReadingInterval
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpeedReadingInterval
impl Debug for SpeedReadingInterval
Sourceimpl Default for SpeedReadingInterval
impl Default for SpeedReadingInterval
Sourcefn default() -> SpeedReadingInterval
fn default() -> SpeedReadingInterval
Returns the “default value” for a type. Read more
Sourceimpl Message for SpeedReadingInterval
impl Message for SpeedReadingInterval
Sourceimpl PartialEq for SpeedReadingInterval
impl PartialEq for SpeedReadingInterval
impl StructuralPartialEq for SpeedReadingInterval