#[non_exhaustive]pub struct TerminalPointId {
pub value: String,
pub id: Option<Id>,
/* private fields */
}๐Deprecated
Deprecated: TerminalPoints are no longer supported in Fleet Engine. Use
TerminalLocation.point instead.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value: String๐Deprecated
Deprecated.
id: Option<Id>๐Deprecated
Deprecated.
Implementations
Sourceimpl TerminalPointId
impl TerminalPointId
Sourcepub fn place_id(&self) -> Option<&String>
๐Deprecated
pub fn place_id(&self) -> Option<&String>
The value of id
if it holds a PlaceId, None if the field is not set or
holds a different branch.
Sourcepub fn set_place_id<T: Into<String>>(self, v: T) -> Self
๐Deprecated
pub fn set_place_id<T: Into<String>>(self, v: T) -> Self
Sourcepub fn generated_id(&self) -> Option<&String>
๐Deprecated
pub fn generated_id(&self) -> Option<&String>
The value of id
if it holds a GeneratedId, None if the field is not set or
holds a different branch.
Sourcepub fn set_generated_id<T: Into<String>>(self, v: T) -> Self
๐Deprecated
pub fn set_generated_id<T: Into<String>>(self, v: T) -> Self