UpdateVehicleRequest

Struct UpdateVehicleRequest 

#[non_exhaustive]
pub struct UpdateVehicleRequest { pub header: Option<RequestHeader>, pub name: String, pub vehicle: Option<Vehicle>, pub update_mask: Option<FieldMask>, /* private fields */ }
`UpdateVehicle request message.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
header: Option<RequestHeader>

The standard Fleet Engine request header.

name: String

Required. Must be in the format providers/{provider}/vehicles/{vehicle}. The {provider} must be the Project ID (for example, sample-cloud-project) of the Google Cloud Project of which the service account making this call is a member.

vehicle: Option<Vehicle>

Required. The Vehicle entity values to apply. When updating a Vehicle, the following fields may not be updated as they are managed by the server.

  • available_capacity
  • current_route_segment_version
  • current_trips
  • name
  • waypoints_version

If the attributes field is updated, all the vehicle’s attributes are replaced with the attributes provided in the request. If you want to update only some attributes, see the UpdateVehicleAttributes method.

Likewise, the waypoints field can be updated, but must contain all the waypoints currently on the vehicle, and no other waypoints.

update_mask: Option<FieldMask>

Required. A field mask indicating which fields of the Vehicle to update. At least one field name must be provided.

Implementations

Source

impl UpdateVehicleRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_header<T>(self, v: T) -> Self
where T: Into<RequestHeader>,

Sets the value of header.

Example
use google_maps_fleetengine_v1::model::RequestHeader;
let x = UpdateVehicleRequest::new().set_header(RequestHeader::default()/* use setters */);
pub fn set_or_clear_header<T>(self, v: Option<T>) -> Self
where T: Into<RequestHeader>,

Sets or clears the value of header.

Example
use google_maps_fleetengine_v1::model::RequestHeader;
let x = UpdateVehicleRequest::new().set_or_clear_header(Some(RequestHeader::default()/* use setters */));
let x = UpdateVehicleRequest::new().set_or_clear_header(None::<RequestHeader>);
pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = UpdateVehicleRequest::new().set_name("example");
pub fn set_vehicle<T>(self, v: T) -> Self
where T: Into<Vehicle>,

Sets the value of vehicle.

Example
use google_maps_fleetengine_v1::model::Vehicle;
let x = UpdateVehicleRequest::new().set_vehicle(Vehicle::default()/* use setters */);
pub fn set_or_clear_vehicle<T>(self, v: Option<T>) -> Self
where T: Into<Vehicle>,

Sets or clears the value of vehicle.

Example
use google_maps_fleetengine_v1::model::Vehicle;
let x = UpdateVehicleRequest::new().set_or_clear_vehicle(Some(Vehicle::default()/* use setters */));
let x = UpdateVehicleRequest::new().set_or_clear_vehicle(None::<Vehicle>);
pub fn set_update_mask<T>(self, v: T) -> Self
where T: Into<FieldMask>,

Sets the value of update_mask.

Example
use wkt::FieldMask;
let x = UpdateVehicleRequest::new().set_update_mask(FieldMask::default()/* use setters */);
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
where T: Into<FieldMask>,

Sets or clears the value of update_mask.

Example
use wkt::FieldMask;
let x = UpdateVehicleRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateVehicleRequest::new().set_or_clear_update_mask(None::<FieldMask>);