#[non_exhaustive]pub struct Waypoint {
pub lat_lng: Option<LatLng>,
pub eta: Option<Timestamp>,
/* private fields */
}Expand description
Describes intermediate points along a route for a VehicleMatch in a
SearchVehiclesResponse. This concept is represented as a TripWaypoint in
all other endpoints.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.lat_lng: Option<LatLng>The location of this waypoint.
eta: Option<Timestamp>The estimated time that the vehicle will arrive at this waypoint.
Implementations
Sourceimpl Waypoint
impl Waypoint
Sourcepub fn set_lat_lng<T>(self, v: T) -> Self
pub fn set_lat_lng<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_lat_lng<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_lat_lng<T>(self, v: Option<T>) -> Self