Example
async fn sample(
provider_id: &str,
trip_id: &str,
) -> anyhow::Result<()> {
let client = TripService::builder().build().await?;
let response = client.get_trip()
.set_name(format!("providers/{provider_id}/trips/{trip_id}"))
.send().await?;
println!("response {:?}", response);
Ok(())
}Concrete implementations of this client library traits.
Structs
- Trip
Service - Implements a client for the Local Rides and Deliveries API.
- Vehicle
Service - Implements a client for the Local Rides and Deliveries API.