The messages and enums that are part of this client library.
Modules
- report_
billable_ trip_ request - Defines additional types related to ReportBillableTripRequest.
- request_
header - Defines additional types related to RequestHeader.
- search_
vehicles_ request - Defines additional types related to SearchVehiclesRequest.
- speed_
reading_ interval - Defines additional types related to SpeedReadingInterval.
- terminal_
point_ id - Defines additional types related to TerminalPointId.
- trip_
attribute - Defines additional types related to TripAttribute.
- vehicle
- Defines additional types related to Vehicle.
- vehicle_
attribute - Defines additional types related to VehicleAttribute.
- vehicle_
match - Defines additional types related to VehicleMatch.
- visual_
traffic_ report_ polyline_ rendering - Defines additional types related to VisualTrafficReportPolylineRendering.
Structs
- Battery
Info - Information about the device’s battery.
- Consumable
Traffic Polyline - Traffic density along a Vehicle’s path.
- Create
Trip Request - CreateTrip request message.
- Create
Vehicle Request CreateVehiclerequest message.- Delete
Trip Request - DeleteTrip request message.
- Delete
Vehicle Request - DeleteVehicle request message.
- Device
Settings - Information about various settings on the mobile device.
- GetTrip
Request - GetTrip request message.
- GetVehicle
Request GetVehiclerequest message.- License
Plate - The license plate information of the Vehicle. To avoid storing personally-identifiable information, only the minimum information about the license plate is stored as part of the entity.
- List
Vehicles Request ListVehiclesrequest message.- List
Vehicles Response ListVehiclesresponse message.- Report
Billable Trip Request - ReportBillableTrip request message.
- Request
Header - A RequestHeader contains fields common to all Fleet Engine RPC requests.
- Search
Trips Request - SearchTrips request message.
- Search
Trips Response - SearchTrips response message.
- Search
Vehicles Request SearchVehiclesrequest message.- Search
Vehicles Response SearchVehiclesresponse message.- Speed
Reading Interval - Traffic density indicator on a contiguous segment of a path. Given a path with points P_0, P_1, … , P_N (zero-based index), the SpeedReadingInterval defines an interval and describes its traffic using the following categories.
- Stop
Location - The actual location where a stop (pickup/dropoff) happened.
- Terminal
Location - Describes the location of a waypoint.
- Terminal
Point Id Deprecated - Deprecated: TerminalPoints are no longer supported in Fleet Engine. Use
TerminalLocation.pointinstead. - Traffic
Polyline Data - Traffic conditions along the expected vehicle route.
- Trip
- Trip metadata.
- Trip
Attribute - Describes a trip attribute as a key-value pair. The “key:value” string length cannot exceed 256 characters.
- Trip
Waypoint - Describes a stopping point on a vehicle’s route or an ending point on a vehicle’s trip.
- Update
Trip Request - UpdateTrip request message.
- Update
Vehicle Attributes Request UpdateVehicleAttributesrequest message.- Update
Vehicle Attributes Response UpdateVehicleAttributesresponse message.- Update
Vehicle Request - `UpdateVehicle request message.
- Vehicle
- Vehicle metadata.
- Vehicle
Attribute - Describes a vehicle attribute as a key-value pair. The “key:value” string length cannot exceed 256 characters.
- Vehicle
Attribute List - A list-of-lists datatype for vehicle attributes.
- Vehicle
Location - The location, speed, and heading of a vehicle at a point in time.
- Vehicle
Match - Contains the vehicle and related estimates for a vehicle that match the
points of active trips for the vehicle
SearchVehiclesRequest. - Visual
Traffic Report Polyline Rendering - Describes how clients should color one portion of the polyline along the route.
- Waypoint
- Describes intermediate points along a route for a
VehicleMatchin aSearchVehiclesResponse. This concept is represented as aTripWaypointin all other endpoints.
Enums
- Battery
Status - Status of the battery, whether full or charging etc.
- Billing
Platform Identifier - A set of values that indicate upon which platform the request was issued.
- Location
Power Save Mode - How location features are configured to behave on the mobile device when the devices “battery saver” feature is on. (https://developer.android.com/reference/android/os/PowerManager#getLocationPowerSaveMode())
- Location
Sensor - The sensor or methodology used to determine the location.
- Navigation
Status - The vehicle’s navigation status.
- Polyline
Format Type - The type of polyline format.
- Power
Source - Type of the charger being used to charge the battery.
- Trip
Status - The status of a trip indicating its progression.
- Trip
Type - The type of a trip.
- Trip
View - Selector for different sets of Trip fields in a
GetTripresponse. See AIP-157 for context. Additional views are likely to be added. - Vehicle
State - The state of a
Vehicle. - Waypoint
Type - The type of waypoint.