#[non_exhaustive]pub enum LocationSensor {
UnknownSensor,
Gps,
Network,
Passive,
RoadSnappedLocationProvider,
CustomerSuppliedLocation,
FleetEngineLocation,
FusedLocationProvider,
CoreLocation,
UnknownValue(UnknownValue),
}Expand description
The sensor or methodology used to determine the location.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
UnknownSensor
The sensor is unspecified or unknown.
Gps
GPS or Assisted GPS.
Network
Assisted GPS, cell tower ID, or WiFi access point.
Passive
Cell tower ID or WiFi access point.
RoadSnappedLocationProvider
A location determined by the mobile device to be the most likely road position.
CustomerSuppliedLocation
A customer-supplied location from an independent source. Typically, this
value is used for a location provided from sources other than the mobile
device running Driver SDK. If the original source is described by one of
the other enum values, use that value. Locations marked
CUSTOMER_SUPPLIED_LOCATION are typically provided via a Vehicle’s
last_location.supplemental_location_sensor.
FleetEngineLocation
A location calculated by Fleet Engine based on the signals available to it. Output only. This value will be rejected if it is received in a request.
FusedLocationProvider
Android’s Fused Location Provider.
CoreLocation
The location provider on Apple operating systems.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LocationSensor::value or LocationSensor::name.
Implementations