#[non_exhaustive]pub struct GetVehicleRequest {
pub header: Option<RequestHeader>,
pub name: String,
pub current_route_segment_version: Option<Timestamp>,
pub waypoints_version: Option<Timestamp>,
/* private fields */
}Expand description
GetVehicle request message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.header: Option<RequestHeader>The standard Fleet Engine request header.
name: StringRequired. Must be in the format
providers/{provider}/vehicles/{vehicle}.
The provider must be the Project ID (for example, sample-cloud-project)
of the Google Cloud Project of which the service account making
this call is a member.
current_route_segment_version: Option<Timestamp>Indicates the minimum timestamp (exclusive) for which
Vehicle.current_route_segment is retrieved.
If the route is unchanged since this timestamp, the current_route_segment
field is not set in the response. If a minimum is unspecified, the
current_route_segment is always retrieved.
waypoints_version: Option<Timestamp>Indicates the minimum timestamp (exclusive) for which Vehicle.waypoints
data is retrieved. If the waypoints are unchanged since this timestamp, the
vehicle.waypoints data is not set in the response. If this field is
unspecified, vehicle.waypoints is always retrieved.
Implementations
Sourceimpl GetVehicleRequest
impl GetVehicleRequest
Sourcepub fn set_header<T>(self, v: T) -> Selfwhere
T: Into<RequestHeader>,
pub fn set_header<T>(self, v: T) -> Selfwhere
T: Into<RequestHeader>,
Sourcepub fn set_or_clear_header<T>(self, v: Option<T>) -> Selfwhere
T: Into<RequestHeader>,
pub fn set_or_clear_header<T>(self, v: Option<T>) -> Selfwhere
T: Into<RequestHeader>,
Sourcepub fn set_current_route_segment_version<T>(self, v: T) -> Self
pub fn set_current_route_segment_version<T>(self, v: T) -> Self
Sets the value of current_route_segment_version.
Example
use wkt::Timestamp;
let x = GetVehicleRequest::new().set_current_route_segment_version(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_current_route_segment_version<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_current_route_segment_version<T>(self, v: Option<T>) -> Self
Sets or clears the value of current_route_segment_version.
Example
use wkt::Timestamp;
let x = GetVehicleRequest::new().set_or_clear_current_route_segment_version(Some(Timestamp::default()/* use setters */));
let x = GetVehicleRequest::new().set_or_clear_current_route_segment_version(None::<Timestamp>);Sourcepub fn set_waypoints_version<T>(self, v: T) -> Self
pub fn set_waypoints_version<T>(self, v: T) -> Self
Sets the value of waypoints_version.
Example
use wkt::Timestamp;
let x = GetVehicleRequest::new().set_waypoints_version(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_waypoints_version<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_waypoints_version<T>(self, v: Option<T>) -> Self
Sets or clears the value of waypoints_version.
Example
use wkt::Timestamp;
let x = GetVehicleRequest::new().set_or_clear_waypoints_version(Some(Timestamp::default()/* use setters */));
let x = GetVehicleRequest::new().set_or_clear_waypoints_version(None::<Timestamp>);Trait Implementations
Sourceimpl Clone for GetVehicleRequest
impl Clone for GetVehicleRequest
Sourcefn clone(&self) -> GetVehicleRequest
fn clone(&self) -> GetVehicleRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more