RequestHeader

Struct RequestHeader 

#[non_exhaustive]
pub struct RequestHeader { pub language_code: String, pub region_code: String, pub sdk_version: String, pub os_version: String, pub device_model: String, pub sdk_type: SdkType, pub maps_sdk_version: String, pub nav_sdk_version: String, pub platform: Platform, pub manufacturer: String, pub android_api_level: i32, pub trace_id: String, /* private fields */ }
A RequestHeader contains fields common to all Fleet Engine RPC requests.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
language_code: String

The BCP-47 language code, such as en-US or sr-Latn. For more information, see http://www.unicode.org/reports/tr35/#Unicode_locale_identifier. If none is specified, the response may be in any language, with a preference for English if such a name exists. Field value example: en-US.

region_code: String

Required. CLDR region code of the region where the request originates. Field value example: US.

sdk_version: String

Version of the calling SDK, if applicable. The version format is “major.minor.patch”, example: 1.1.2.

os_version: String

Version of the operating system on which the calling SDK is running. Field value examples: 4.4.1, 12.1.

device_model: String

Model of the device on which the calling SDK is running. Field value examples: iPhone12,1, SM-G920F.

sdk_type: SdkType

The type of SDK sending the request.

maps_sdk_version: String

Version of the MapSDK which the calling SDK depends on, if applicable. The version format is “major.minor.patch”, example: 5.2.1.

nav_sdk_version: String

Version of the NavSDK which the calling SDK depends on, if applicable. The version format is “major.minor.patch”, example: 2.1.0.

platform: Platform

Platform of the calling SDK.

manufacturer: String

Manufacturer of the Android device from the calling SDK, only applicable for the Android SDKs. Field value example: Samsung.

android_api_level: i32

Android API level of the calling SDK, only applicable for the Android SDKs. Field value example: 23.

trace_id: String

Optional ID that can be provided for logging purposes in order to identify the request.

Implementations

Source

impl RequestHeader

pub fn new() -> Self

Creates a new default instance.

pub fn set_language_code<T: Into<String>>(self, v: T) -> Self

Sets the value of language_code.

Example
let x = RequestHeader::new().set_language_code("example");
pub fn set_region_code<T: Into<String>>(self, v: T) -> Self

Sets the value of region_code.

Example
let x = RequestHeader::new().set_region_code("example");
pub fn set_sdk_version<T: Into<String>>(self, v: T) -> Self

Sets the value of sdk_version.

Example
let x = RequestHeader::new().set_sdk_version("example");
pub fn set_os_version<T: Into<String>>(self, v: T) -> Self

Sets the value of os_version.

Example
let x = RequestHeader::new().set_os_version("example");
pub fn set_device_model<T: Into<String>>(self, v: T) -> Self

Sets the value of device_model.

Example
let x = RequestHeader::new().set_device_model("example");
pub fn set_sdk_type<T: Into<SdkType>>(self, v: T) -> Self

Sets the value of sdk_type.

Example
use google_maps_fleetengine_v1::model::request_header::SdkType;
let x0 = RequestHeader::new().set_sdk_type(SdkType::Consumer);
let x1 = RequestHeader::new().set_sdk_type(SdkType::Driver);
let x2 = RequestHeader::new().set_sdk_type(SdkType::Javascript);
pub fn set_maps_sdk_version<T: Into<String>>(self, v: T) -> Self

Sets the value of maps_sdk_version.

Example
let x = RequestHeader::new().set_maps_sdk_version("example");
pub fn set_nav_sdk_version<T: Into<String>>(self, v: T) -> Self

Sets the value of nav_sdk_version.

Example
let x = RequestHeader::new().set_nav_sdk_version("example");
pub fn set_platform<T: Into<Platform>>(self, v: T) -> Self

Sets the value of platform.

Example
use google_maps_fleetengine_v1::model::request_header::Platform;
let x0 = RequestHeader::new().set_platform(Platform::Android);
let x1 = RequestHeader::new().set_platform(Platform::Ios);
let x2 = RequestHeader::new().set_platform(Platform::Web);
pub fn set_manufacturer<T: Into<String>>(self, v: T) -> Self

Sets the value of manufacturer.

Example
let x = RequestHeader::new().set_manufacturer("example");
pub fn set_android_api_level<T: Into<i32>>(self, v: T) -> Self

Sets the value of android_api_level.

Example
let x = RequestHeader::new().set_android_api_level(42);
pub fn set_trace_id<T: Into<String>>(self, v: T) -> Self

Sets the value of trace_id.

Example
let x = RequestHeader::new().set_trace_id("example");